@@ -584,10 +584,10 @@ class DataTransform(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=self.instance.id,
-            extra=self.instance.datatransformerconstants_set.count() + 1,
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
+        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
 
         self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
             instance=self.instance,
@@ -595,9 +595,9 @@ class DataTransform(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=self.instance.id,
-            extra=self.instance.hardwaredatatransformer_set.count() + 1,
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
         )
+        self.nested_hardware_outputs_form.extra = self.instance.hardwaredatatransformer_set.count() + 1
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
             instance=self.instance,
@@ -605,10 +605,11 @@ class DataTransform(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=self.instance.id,
-            extra=self.instance.hardwarestatsdatatransformer_set.count() + 1,
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
+        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count() + 1
+
 
     def as_p(self):
         print('wtf')
@@ -725,10 +726,10 @@ class DataTransformRoot(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=self.instance.id,
-            extra=self.instance.datatransformerconstants_set.count() + 1,
-            initial=[{'data_transformer':self.instance,'id':str(uuid.uuid4())}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
+        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
 
         self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
             instance=self.instance,
@@ -736,9 +737,9 @@ class DataTransformRoot(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=self.instance.id,
-            extra=self.instance.hardwaredatatransformer_set.count() + 1,
-            initial=[{'data_transformer':self.instance,'id':str(uuid.uuid4())}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
         )
+        self.nested_hardware_outputs_form.extra = self.instance.hardwaredatatransformer_set.count() + 1
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
             instance=self.instance,
@@ -746,10 +747,10 @@ class DataTransformRoot(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=self.instance.id,
-            extra=self.instance.hardwarestatsdatatransformer_set.count() + 1,
-            initial=[{'data_transformer':self.instance,'id':str(uuid.uuid4())}]
+            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
+        self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count() + 1
 
     def as_p(self):
         print('root')
